magneticalc.QtWidgets2.QButtons.QButtons

# ``magneticalc`.`QtWidgets2`.`QButtons`.`QButtons``

class documentation

`class QButtons(QHBoxLayout):`

Constructor: `QButtons(data)`

View In Hierarchy

QButtons class.

Method | `__init__` | Initializes a horizontal layout containing multiple buttons.
Instance Variable | `dictionary` | Undocumented

def __init__(self, data: `dict[str, tuple[str, Callable]]`):

Initializes a horizontal layout containing multiple buttons.

Parameters
data: `dict[str, tuple[str, Callable]]` | Dictionary {text: (icon, callback)}

dictionary: `dict[int, QPushButton]` =

Undocumented